@@ -29,14 +29,14 @@ class EditorialBoardLockAPIUnitTest(TestCase):
         Editorial Board Locks API
         """
         req = Client()
-        user = ContextUnitTest.create_user()
+        user = ContextUnitTest.create_user(is_staff=True)
         user2 = ContextUnitTest.create_user(username='staff',
                                             is_staff=True)
 
         webpath = ContextUnitTest.create_webpath()
         webpath_ct = ContentType.objects.get_for_model(webpath)
 
-        # webpath redis redislocks list
+        # webpath redis lock get
         url = reverse('unicms_api:editorial-board-redis-lock',
                       kwargs={'content_type_id': webpath_ct.pk,
                               'object_id': webpath.pk})
@@ -44,13 +44,21 @@ class EditorialBoardLockAPIUnitTest(TestCase):
         # accessible to staff users only
         res = req.get(url)
         assert res.status_code == 403
-        user.is_staff = True
         user.is_superuser = True
         user.save()
         req.force_login(user)
         res = req.get(url)
         assert isinstance(res.json(), dict)
 
+        # webpath redis redislocks set
+        url = reverse('unicms_api:editorial-board-redis-lock-set')
+
+        data = {'content_type_id': webpath_ct.pk,
+                'object_id': webpath.pk}
+        res = req.post(url, data,
+                       content_type='application/json', follow=1)
+        assert isinstance(res.json(), dict)
+
         # webpath locks list
         url = reverse('unicms_api:editorial-board-locks',
                       kwargs={'content_type_id': webpath_ct.pk,
