@@ -1,5 +1,6 @@
 import logging
 
+from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
 from django.test import Client, TestCase
 from django.urls import reverse
@@ -96,6 +97,14 @@ class PageBlockAPIUnitTest(TestCase):
         res = req.get(url, content_type='application/json',)
         assert isinstance(res.json(), dict)
 
+        # redis lock set
+        ct = ContentType.objects.get_for_model(page_block)
+        data = {'content_type_id': ct.pk,
+                'object_id': page_block.pk}
+        res = req.post(url, data,
+                       content_type='application/json', follow=1)
+        assert isinstance(res.json(), dict)
+
         # GET, patch, put, delete
         url = reverse('unicms_api:editorial-board-site-webpath-page-block',
                       kwargs={'site_id': site.pk,
