@@ -71,6 +71,14 @@ class PublicationLocalizationAPIUnitTest(TestCase):
         res = req.get(url, content_type='application/json',)
         assert isinstance(res.json(), dict)
 
+        # redis lock set
+        ct = ContentType.objects.get_for_model(localization)
+        data = {'content_type_id': ct.pk,
+                'object_id': localization.pk}
+        res = req.post(url, data,
+                       content_type='application/json', follow=1)
+        assert isinstance(res.json(), dict)
+
         # GET, patch, put, delete
         url = reverse('unicms_api:editorial-board-publication-localization',
                       kwargs={'publication_id': pub.pk,
