@@ -1,16 +1,19 @@
-from django.urls import path
+from django.urls import path, re_path
+from django.views.generic import TemplateView
 
 from . views import (carousel, carousel_item, carousel_item_link,
                      carousel_item_link_localization,
                      carousel_item_localization,
+                     contact, contact_info, contact_localization,
+                     contact_info_localization,
                      media, media_collection, media_collection_item,
                      publication, publication_attachment,
                      publication_link, publication_localization,
                      publication_media_collection, publication_block,
                      publication_related,
                      website, webpath, webpath_pub_context,
-                     page, page_block, page_carousel, page_link,
-                     page_media, page_media_collection,
+                     page, page_block, page_carousel, page_contact,
+                     page_link, page_media, page_media_collection,
                      page_menu, page_publication,
                      page_heading, page_heading_localization,
                      page_related, page_localization, page_template,
@@ -20,8 +23,15 @@ from . views import (carousel, carousel_item, carousel_item_link,
 
 urlpatterns = []
 
+urlpatterns += re_path(r'api/$',
+                       TemplateView.as_view(
+                        template_name='redoc.html',
+                        extra_context={'schema_url':'openapi-schema'}
+                           ),
+                       name='unicms-api-redoc'),
+
 # Public API Resources
-urlpatterns += path('api/contexts', publication.ApiContext.as_view(), name='api-contexts'),
+# urlpatterns += path('api/contexts', publication.ApiContext.as_view(), name='api-contexts'),
 
 # I would have preferred a regexp .. but openapi schema generator ...
 # re_path('api/news/by-context/(?P<webpath_id>\d+)/?(?P<category_name>[a-zA-Z0-9]*)?'
@@ -47,6 +57,7 @@ urlpatterns += path(f'{m_prefix}/<int:pk>/logs/', media.MediaLogsView.as_view(),
 urlpatterns += path(f'{m_prefix}/form/', media.MediaFormView.as_view(), name='media-form'),
 urlpatterns += path(f'{m_prefix}/options/', media.MediaOptionList.as_view(), name='media-options'),
 urlpatterns += path(f'{m_prefix}/options/<int:pk>/', media.MediaOptionView.as_view(), name='media-option'),
+urlpatterns += path(f'{m_prefix}/allowed-filetypes/', media.MediaFileTypeAllowedList.as_view(), name='media-filetype-list'),
 
 # media collections
 mc_prefix = f'{eb_prefix}/media-collections'
@@ -109,6 +120,43 @@ urlpatterns += path(f'{cilil_prefix}/<int:pk>/logs/',
 urlpatterns += path(f'{cilil_prefix}/form/', carousel_item_link_localization.CarouselItemLinkLocalizationFormView.as_view(),
                     name='carousel-item-link-localization-form'),
 
+# contacts
+co_prefix = f'{eb_prefix}/contacts'
+urlpatterns += path(f'{co_prefix}/', contact.ContactList.as_view(), name='contacts'),
+urlpatterns += path(f'{co_prefix}/<int:pk>/', contact.ContactView.as_view(), name='contact'),
+urlpatterns += path(f'{co_prefix}/<int:pk>/logs/', contact.ContactLogsView.as_view(), name='contact-logs'),
+urlpatterns += path(f'{co_prefix}/form/', contact.ContactFormView.as_view(), name='contact-form'),
+urlpatterns += path(f'{co_prefix}/options/', contact.ContactOptionList.as_view(), name='contact-options'),
+urlpatterns += path(f'{co_prefix}/options/<int:pk>/', contact.ContactOptionView.as_view(), name='contact-option'),
+
+# contact localizations
+colo_prefix = f'{co_prefix}/<int:contact_id>/localizations'
+urlpatterns += path(f'{colo_prefix}/', contact_localization.ContactLocalizationList.as_view(), name='contact-localizations'),
+urlpatterns += path(f'{colo_prefix}/<int:pk>/', contact_localization.ContactLocalizationView.as_view(),
+                    name='contact-localization'),
+urlpatterns += path(f'{colo_prefix}/<int:pk>/logs/', contact_localization.ContactLocalizationLogsView.as_view(),
+                    name='contact-localization-logs'),
+urlpatterns += path(f'{colo_prefix}/form/', contact_localization.ContactLocalizationFormView.as_view(),
+                    name='contact-localization-form'),
+
+# contact infos
+coi_prefix = f'{co_prefix}/<int:contact_id>/infos'
+urlpatterns += path(f'{coi_prefix}/', contact_info.ContactInfoList.as_view(), name='contact-infos'),
+urlpatterns += path(f'{coi_prefix}/<int:pk>/', contact_info.ContactInfoView.as_view(), name='contact-info'),
+urlpatterns += path(f'{coi_prefix}/<int:pk>/logs/', contact_info.ContactInfoLogsView.as_view(), name='contact-info-logs'),
+urlpatterns += path(f'{coi_prefix}/form/', contact_info.ContactInfoFormView.as_view(), name='contact-info-form'),
+urlpatterns += path(f'{co_prefix}/infos/form/', contact_info.ContactInfoGenericFormView.as_view(), name='contact-info-form-generic'),
+
+# contact info localizations
+coilo_prefix = f'{coi_prefix}/<int:contact_info_id>/localizations'
+urlpatterns += path(f'{coilo_prefix}/', contact_info_localization.ContactInfoLocalizationList.as_view(), name='contact-info-localizations'),
+urlpatterns += path(f'{coilo_prefix}/<int:pk>/', contact_info_localization.ContactInfoLocalizationView.as_view(),
+                    name='contact-info-localization'),
+urlpatterns += path(f'{coilo_prefix}/<int:pk>/logs/', contact_info_localization.ContactInfoLocalizationLogsView.as_view(),
+                    name='contact-info-localization-logs'),
+urlpatterns += path(f'{coilo_prefix}/form/', contact_info_localization.ContactInfoLocalizationFormView.as_view(),
+                    name='contact-info-localization-form'),
+
 # websites
 urlpatterns += path(f'{eb_prefix}/sites/', website.EditorWebsiteList.as_view(), name='editorial-board-sites'),
 urlpatterns += path(f'{eb_prefix}/sites/<int:pk>/', website.EditorWebsiteView.as_view(), name='editorial-board-site'),
@@ -182,6 +230,14 @@ urlpatterns += path(f'{pac_prefix}/<int:pk>/logs/', page_carousel.PageCarouselLo
                     name='editorial-board-site-webpath-page-carousel-logs'),
 urlpatterns += path(f'{pac_prefix}/form/', page_carousel.PageCarouselFormView.as_view(), name='editorial-board-site-webpath-page-carousel-form'),
 
+# page contacts
+paco_prefix = f'{pa_prefix}/<int:page_id>/contacts'
+urlpatterns += path(f'{paco_prefix}/', page_contact.PageContactList.as_view(), name='editorial-board-site-webpath-page-contacts'),
+urlpatterns += path(f'{paco_prefix}/<int:pk>/', page_contact.PageContactView.as_view(), name='editorial-board-site-webpath-page-contact'),
+urlpatterns += path(f'{paco_prefix}/<int:pk>/logs/', page_contact.PageContactLogsView.as_view(),
+                    name='editorial-board-site-webpath-page-contact-logs'),
+urlpatterns += path(f'{paco_prefix}/form/', page_contact.PageContactFormView.as_view(), name='editorial-board-site-webpath-page-contact-form'),
+
 # page localizations
 palo_prefix = f'{pa_prefix}/<int:page_id>/localizations'
 urlpatterns += path(f'{palo_prefix}/', page_localization.PageLocalizationList.as_view(), name='editorial-board-site-webpath-page-localizations'),
@@ -286,8 +342,10 @@ urlpatterns += path(f'{puli_prefix}/form/', publication_link.PublicationLinkForm
 
 # publication media collections
 pug_prefix = f'{pu_prefix}/<int:publication_id>/media-collections'
-urlpatterns += path(f'{pug_prefix}/', publication_media_collection.PublicationMediaCollectionList.as_view(), name='editorial-board-publication-media-collections'),
-urlpatterns += path(f'{pug_prefix}/<int:pk>/', publication_media_collection.PublicationMediaCollectionView.as_view(), name='editorial-board-publication-media-collection'),
+urlpatterns += path(f'{pug_prefix}/', publication_media_collection.PublicationMediaCollectionList.as_view(),
+                    name='editorial-board-publication-media-collections'),
+urlpatterns += path(f'{pug_prefix}/<int:pk>/', publication_media_collection.PublicationMediaCollectionView.as_view(),
+                    name='editorial-board-publication-media-collection'),
 urlpatterns += path(f'{pug_prefix}/<int:pk>/logs/', publication_media_collection.PublicationMediaCollectionLogsView.as_view(),
                     name='editorial-board-publication-media-collection-logs'),
 urlpatterns += path(f'{pug_prefix}/form/', publication_media_collection.PublicationMediaCollectionFormView.as_view(),
@@ -368,4 +426,5 @@ urlpatterns += path(f'{eb_prefix}/redis-lock/set/',
 # users
 u_prefix = f'{eb_prefix}/users'
 # urlpatterns += path(f'{u_prefix}/form/', webpath_pub_context.EditorialBoardLockUserFormView.as_view(), name='users-form'),
+urlpatterns += path(f'{u_prefix}/<int:user_id>/', users.UserDetail.as_view(), name='user-detail'),
 urlpatterns += path(f'{u_prefix}/current/', users.CurrentUserIDView.as_view(), name='users-current'),
