@@ -1,6 +1,4 @@
 import logging
-import random
-import string
 
 from django.utils.safestring import SafeString
 
@@ -95,6 +93,20 @@ class CarouselPlaceHolder(AbstractPlaceholder):
         return {**self.content,**data}
 
 
+class ContactPlaceHolder(AbstractPlaceholder):
+    collection_name = 'contacts'
+    ph_name = 'cms.templates.blocks.ContactPlaceholderBlock'
+
+    def __init__(self, context:dict, content:dict):
+        super().__init__(context, content)
+        self.contacts = self.page.get_contacts()
+
+    def build_data_dict(self):
+        data = {'contact': self.entry.contact.localized(self.language),
+                'contact_infos': self.entry.contact.get_infos(self.language)}
+        return {**self.content,**data}
+
+
 class LinkPlaceHolder(AbstractPlaceholder):
     collection_name = 'links'
     ph_name = 'cms.templates.blocks.LinkPlaceholderBlock'
@@ -106,7 +118,8 @@ class LinkPlaceHolder(AbstractPlaceholder):
     def build_data_dict(self):
         data = {'name': self.entry.name,
                 'url': self.entry.url,
-                'request': self.request}
+                'request': self.request,
+                'uid': f'id_{self.entry.pk}'}
         return {**self.content,**data}
 
 
@@ -201,6 +214,10 @@ def load_carousel_placeholder(*args, **kwargs):
     return CarouselPlaceHolder(*args, **kwargs)()
 
 
+def load_contact_placeholder(*args, **kwargs):
+    return ContactPlaceHolder(*args, **kwargs)()
+
+
 def load_link_placeholder(*args, **kwargs):
     return LinkPlaceHolder(*args, **kwargs)()
 
